<?php
/**
 * @package Bloom - Creative Responsive Photography / Portfolio WordPress Theme
 * @author CTHthemes - http://themeforest.net/user/cththemes
 * @date: 16-02-2017
 * @version: 1.0
 * @copyright  Copyright ( C ) 2015 cththemes.com . All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 */

if (!isset($bloom_options) && file_exists(get_template_directory() . '/functions/admin-config.php')) {
    require_once (get_template_directory() . '/functions/admin-config.php');
}

function bloom_removeDemoModeLink() { // Be sure to rename this function to something more unique
    // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
        // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
        remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );    
    }
}


add_action('init', 'bloom_removeDemoModeLink');

if(!function_exists('bloom_content_width')){
    /**
     * Sets the content width in pixels, based on the theme's design and stylesheet.
     *
     * Priority 0 to make it available to lower priority callbacks.
     *
     * @global int $content_width
     *
     * @since Bloom 1.0
     */
    function bloom_content_width() {
        $GLOBALS['content_width'] = apply_filters( 'bloom_content_width', 618 );
    }
    add_action( 'after_setup_theme', 'bloom_content_width', 0 );

}

if (!function_exists('bloom_setup_theme')) {
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     *
     * @since Bloom 1.0
     */

    function bloom_setup_theme() {
        global $bloom_options;
        /* replace local link with this '.addcslashes( home_url('/' ) ,'/').' */
        /* echo default options string - var_dump(json_encode($bloom_options));die; */
        $lang = get_template_directory() . '/languages';
        load_theme_textdomain('bloom', $lang);
        
        add_theme_support('post-thumbnails');

        if(isset($bloom_options['enable_custom_sizes']) && $bloom_options['enable_custom_sizes']){
            //get thumbnail sizes option
            $sizes = bloom_get_thumbnail_size();
            
            add_image_size('bloomfuls-thumb', $sizes['fuls']['width'], $sizes['fuls']['height'], $sizes['fuls']['hard_crop']);
            add_image_size('bloomhoz-thumb', $sizes['hoz']['width'], $sizes['hoz']['height'], $sizes['hoz']['hard_crop']);
            add_image_size('bloomver-size-one', $sizes['galma1']['width'], $sizes['galma1']['height'], $sizes['galma1']['hard_crop']);
            add_image_size('bloomver-size-second', $sizes['galma2']['width'], $sizes['galma2']['height'], $sizes['galma2']['hard_crop']);
            add_image_size('bloomver-size-three', $sizes['galma3']['width'], $sizes['galma3']['height'], $sizes['galma3']['hard_crop']);
            add_image_size('bloom-gallery', $sizes['galgrid']['width'], $sizes['galgrid']['height'], $sizes['galgrid']['hard_crop']);
            add_image_size('bloom-thumb', $sizes['blog']['width'], $sizes['blog']['height'], $sizes['blog']['hard_crop']);
            add_image_size('bloom-large', $sizes['bloglarge']['width'], $sizes['bloglarge']['height'], $sizes['bloglarge']['hard_crop']);
            add_image_size('bloommember-thumb', $sizes['team']['width'], $sizes['team']['height'], $sizes['team']['hard_crop']);
        }
        
        
        // Adds RSS feed links to <head> for posts and comments.
        add_theme_support('automatic-feed-links');
        
        // Switches default core markup for search form, comment form, and comments
        
        //add_theme_support('widgets');
        add_theme_support('title-tag');
        
        // to output valid HTML5.
        add_theme_support('html5', array('search-form', 'comment-form', 'comment-list'));
        
        //Post formats
        add_theme_support('post-formats', array('audio', 'gallery', 'image', 'link', 'quote', 'status', 'video'));

        add_theme_support('custom-header');

        add_theme_support('custom-background');

        // from version 2.0
        add_theme_support( 'woocommerce' );
        
        // This theme uses wp_nav_menu() in one location.
        register_nav_menu('primary', esc_html__('Primary Menu', 'bloom'));
        
        add_filter('use_default_gallery_style', '__return_false');

        add_editor_style(get_template_directory_uri().'/inc/assets/custom-editor-style.css');
    }
}
add_action('after_setup_theme', 'bloom_setup_theme');

if(!function_exists('bloom_get_thumbnail_size')){
    function bloom_get_thumbnail_size(){
        global $bloom_options;
        $sizes = array();

        //Horizontal Slider
        if(isset($bloom_options['fullscreen_thumb'])){
            $sizes['fuls'] = array();
            $sizes['fuls']['width'] = isset($bloom_options['fullscreen_thumb']['width']) ? $bloom_options['fullscreen_thumb']['width'] : '9999';
            $sizes['fuls']['height'] = isset($bloom_options['fullscreen_thumb']['height']) ? $bloom_options['fullscreen_thumb']['height'] : '9999';
            $sizes['fuls']['hard_crop'] = isset($bloom_options['fullscreen_thumb']['hard_crop']) ? $bloom_options['fullscreen_thumb']['hard_crop'] : 1;
        }else{
            $sizes['fuls'] = array(
                'width' => '9999',
                'height' => '9999',
                'hard_crop' => 1,
            );
        }

        

        //Horizontal Layout
        if(isset($bloom_options['horizontal_slider_thumb'])){
            $sizes['hoz'] = array();
            $sizes['hoz']['width'] = isset($bloom_options['horizontal_slider_thumb']['width']) ? $bloom_options['horizontal_slider_thumb']['width'] : '9999';
            $sizes['hoz']['height'] = isset($bloom_options['horizontal_slider_thumb']['height']) ? $bloom_options['horizontal_slider_thumb']['height'] : '9999';
            $sizes['hoz']['hard_crop'] = isset($bloom_options['horizontal_slider_thumb']['hard_crop']) ? $bloom_options['horizontal_slider_thumb']['hard_crop'] : 1;
        }else{
            $sizes['hoz'] = array(
                'width' => '9999',
                'height' => '9999',
                'hard_crop' => 1,
            );
        }


        //Masonry size one
        if(isset($bloom_options['galmasonry_thumbnail_size_one'])){
            $sizes['galma1'] = array();
            $sizes['galma1']['width'] = isset($bloom_options['galmasonry_thumbnail_size_one']['width']) ? $bloom_options['galmasonry_thumbnail_size_one']['width'] : '9999';
            $sizes['galma1']['height'] = isset($bloom_options['galmasonry_thumbnail_size_one']['height']) ? $bloom_options['galmasonry_thumbnail_size_one']['height'] : '9999';
            $sizes['galma1']['hard_crop'] = isset($bloom_options['galmasonry_thumbnail_size_one']['hard_crop']) ? $bloom_options['galmasonry_thumbnail_size_one']['hard_crop'] : 1;
        }else{
            $sizes['galma1'] = array(
                'width' => '9999',
                'height' => '9999',
                'hard_crop' => 1,
            );
        }


        //Masonry size two
        if(isset($bloom_options['galmasonry_thumbnail_size_two'])){
            $sizes['galma2'] = array();
            $sizes['galma2']['width'] = isset($bloom_options['galmasonry_thumbnail_size_two']['width']) ? $bloom_options['galmasonry_thumbnail_size_two']['width'] : '9999';
            $sizes['galma2']['height'] = isset($bloom_options['galmasonry_thumbnail_size_two']['height']) ? $bloom_options['galmasonry_thumbnail_size_two']['height'] : '9999';
            $sizes['galma2']['hard_crop'] = isset($bloom_options['galmasonry_thumbnail_size_two']['hard_crop']) ? $bloom_options['galmasonry_thumbnail_size_two']['hard_crop'] : 1;
        }else{
            $sizes['galma2'] = array(
                'width' => '9999',
                'height' => '9999',
                'hard_crop' => 1,
            );
        }

        //Masonry size three
        if(isset($bloom_options['galmasonry_thumbnail_size_three'])){
            $sizes['galma3'] = array();
            $sizes['galma3']['width'] = isset($bloom_options['galmasonry_thumbnail_size_three']['width']) ? $bloom_options['galmasonry_thumbnail_size_three']['width'] : '9999';
            $sizes['galma3']['height'] = isset($bloom_options['galmasonry_thumbnail_size_three']['height']) ? $bloom_options['galmasonry_thumbnail_size_three']['height'] : '9999';
            $sizes['galma3']['hard_crop'] = isset($bloom_options['galmasonry_thumbnail_size_three']['hard_crop']) ? $bloom_options['galmasonry_thumbnail_size_three']['hard_crop'] : 1;
        }else{
            $sizes['galma3'] = array(
                'width' => '9999',
                'height' => '9999',
                'hard_crop' => 1,
            );
        }

        //Gallery size
        if(isset($bloom_options['galgrid_thumbnail_size'])){
            $sizes['galgrid'] = array();
            $sizes['galgrid']['width'] = isset($bloom_options['galgrid_thumbnail_size']['width']) ? $bloom_options['galgrid_thumbnail_size']['width'] : '9999';
            $sizes['galgrid']['height'] = isset($bloom_options['galgrid_thumbnail_size']['height']) ? $bloom_options['galgrid_thumbnail_size']['height'] : '9999';
            $sizes['galgrid']['hard_crop'] = isset($bloom_options['galgrid_thumbnail_size']['hard_crop']) ? $bloom_options['galgrid_thumbnail_size']['hard_crop'] : 1;
        }else{
            $sizes['galgrid'] = array(
                'width' => '9999',
                'height' => '9999',
                'hard_crop' => 1,
            );
        }

        //Blog Post thumbnail
        if(isset($bloom_options['blog_image_thumb'])){
            $sizes['blog'] = array();
            $sizes['blog']['width'] = isset($bloom_options['blog_image_thumb']['width']) ? $bloom_options['blog_image_thumb']['width'] : '9999';
            $sizes['blog']['height'] = isset($bloom_options['blog_image_thumb']['height']) ? $bloom_options['blog_image_thumb']['height'] : '9999';
            $sizes['blog']['hard_crop'] = isset($bloom_options['blog_image_thumb']['hard_crop']) ? $bloom_options['blog_image_thumb']['hard_crop'] : 1;
        }else{
            $sizes['blog'] = array(
                'width' => '9999',
                'height' => '9999',
                'hard_crop' => 1,
            );
        }

        //Blog Post large thumb
        if(isset($bloom_options['blog_image_large_thumb'])){
            $sizes['bloglarge'] = array();
            $sizes['bloglarge']['width'] = isset($bloom_options['blog_image_thumb']['width']) ? $bloom_options['blog_image_thumb']['width'] : '9999';
            $sizes['bloglarge']['height'] = isset($bloom_options['blog_image_thumb']['height']) ? $bloom_options['blog_image_thumb']['height'] : '9999';
            $sizes['bloglarge']['hard_crop'] = isset($bloom_options['blog_image_thumb']['hard_crop']) ? $bloom_options['blog_image_thumb']['hard_crop'] : 1;
        }else{
            $sizes['bloglarge'] = array(
                'width' => '9999',
                'height' => '9999',
                'hard_crop' => 1,
            );
        }
        


        

        //Team Member Parallax
        if(isset($bloom_options['team_member_thumb'])){
            $sizes['team'] = array();
            $sizes['team']['width'] = isset($bloom_options['team_member_thumb']['width']) ? $bloom_options['team_member_thumb']['width'] : '9999';
            $sizes['team']['height'] = isset($bloom_options['team_member_thumb']['height']) ? $bloom_options['team_member_thumb']['height'] : '9999';
            $sizes['team']['hard_crop'] = isset($bloom_options['team_member_thumb']['hard_crop']) ? $bloom_options['team_member_thumb']['hard_crop'] : 1;
        }else{
            $sizes['team'] = array(
                'width' => '9999',
                'height' => '9999',
                'hard_crop' => 1,
            );
        }

       
        

        return $sizes;
    }
}

/**
 * Register widget area.
 *
 * @since Bloom 1.0
 *
 * @link https://codex.wordpress.org/Function_Reference/register_sidebar
 */
function bloom_register_sidebars() {
    
    register_sidebar(
        array(
            'name' => esc_html__('Main Sidebar', 'bloom'), 
            'id' => 'sidebar-1', 
            'description' => esc_html__('Appears in the sidebar section of the site.', 'bloom'), 
            'before_widget' => '<div id="%1$s" class="widget bloom-mainsidebar-widget main-sidebar-widget %2$s">', 
            'after_widget' => '</div>', 
            'before_title' => '<h3 class="wid-title">', 
            'after_title' => '</h3><div class="clearfix"></div>',
        )
    );
    
    register_sidebar(
        array(
            'name' => esc_html__('Page Sidebar', 'bloom'), 
            'id' => 'sidebar-2', 
            'description' => esc_html__('Appears in the sidebar section of the page template.', 'bloom'), 
            'before_widget' => '<div id="%1$s" class="widget bloom-pagesidebar-width main-sidebar-widget %2$s">', 
            'after_widget' => '</div>', 
            'before_title' => '<h3 class="wid-title">', 
            'after_title' => '</h3><div class="clearfix"></div>',
        )
    );

}

add_action('widgets_init', 'bloom_register_sidebars');

if(!function_exists('bloom_slbd_count_widgets')){
   /**
     * Count number of widgets in a sidebar
     * Used to add classes to widget areas so widgets can be displayed one, two, three or four per row
     */
    function bloom_slbd_count_widgets($sidebar_id) {
        
        // If loading from front page, consult $_wp_sidebars_widgets rather than options
        // to see if wp_convert_widget_settings() has made manipulations in memory.
        global $_wp_sidebars_widgets;
        if (empty($_wp_sidebars_widgets)):
            $_wp_sidebars_widgets = get_option('sidebars_widgets', array());
        endif;
        
        $sidebars_widgets_count = $_wp_sidebars_widgets;
        
        if (isset($sidebars_widgets_count[$sidebar_id])):
            $widget_count = count($sidebars_widgets_count[$sidebar_id]);
            $widget_classes = 'widget-count-' . count($sidebars_widgets_count[$sidebar_id]);
            if ($widget_count % 6 == 0 && $widget_count >= 6):
                
                // Six widgets er row if there are exactly four or more than six
                $widget_classes.= ' col-md-2';
            elseif ($widget_count % 4 == 0 && $widget_count >= 4):
                
                // Four widgets er row if there are exactly four or more than six
                $widget_classes.= ' col-md-3';
            elseif ($widget_count % 3 == 0 && $widget_count >= 3):
                
                // Three widgets per row if there's three or more widgets
                $widget_classes.= ' col-md-4';
            elseif (2 == $widget_count):
                
                // Otherwise show two widgets per row
                $widget_classes.= ' col-md-6';
            elseif (1 == $widget_count):
                
                // Otherwise show two widgets per row
                $widget_classes.= ' col-md-12';
            endif;
            
            return $widget_classes;
        endif;
    } 
}

if ( ! function_exists( 'bloom_google_fonts_url' ) ) {
    /**
     * Register Google fonts.
     *
     * @return string Google fonts URL for the theme.
     */
    function bloom_google_fonts_url() {
        $fonts_url = '';
        $fonts     = array();
        $subsets   = 'latin,latin-ext';

        
        if ( 'off' !== esc_html_x( 'on', 'Libre Baskerville font: on or off', 'bloom' ) ) {
            $fonts[] = 'Libre Baskerville:400,400i,700';
        }

        
        if ( 'off' !== esc_html_x( 'on', 'Montserrat font: on or off', 'bloom' ) ) {
            $fonts[] = 'Montserrat:400,700';
        }

        
        if ( 'off' !== esc_html_x( 'on', 'Questrial font: on or off', 'bloom' ) ) {
            $fonts[] = 'Questrial';
        }

        if ( $fonts ) {
            $fonts_url = add_query_arg( array(
                'family' => urlencode( implode( '|', $fonts ) ),
                'subset' => urlencode( $subsets ),
            ), 'https://fonts.googleapis.com/css' );
        }

        return $fonts_url;

    }

}

/**
 * Enqueue scripts and styles.
 *
 * @since Bloom 1.0
 */

if (!function_exists('bloom_scripts_styles')) {
    function bloom_scripts_styles() {
        global $bloom_options;
        $demo_color = get_query_var( 'color', 'light');
        if($demo_color == 'dark') {
            $bloom_options['color-preset'] = 'dark';
        }

        if (is_singular() && comments_open() && get_option('thread_comments')) {
            wp_enqueue_script('comment-reply');
        }
        wp_enqueue_script("bloomplugins-js", get_template_directory_uri() . "/js/plugins.js", array('jquery'), null, true);
        wp_enqueue_script("bloomcore-js", get_template_directory_uri() . "/js/core.min.js", array(), null, true);
        wp_enqueue_script("bloomscripts-js", get_template_directory_uri() . "/js/scripts.js", array(), null, true);
        $bloom_datas = array();
        $bloom_datas['enable_ajax'] = $bloom_options['enable_ajax_transition'];
        $bloom_datas['nf_bg'] = $bloom_options['bg404']['url'];
        $bloom_datas['nf_msg'] = $bloom_options['404_intro'];
        $bloom_datas['nf_linktext'] = _x('Back to the last page','not found link text','bloom');
        wp_localize_script( 'bloomscripts-js', '_bloom', $bloom_datas );

        if($bloom_options['enable_ajax_transition']){
            wp_enqueue_script('comment-reply');
            
            wp_enqueue_script("wpb_composer_front_js", plugins_url() . '/js_composer/assets/js/dist/js_composer_front.min.js', array('jquery'), null, true);

            wp_register_script( 'vc_accordion_script', plugins_url() . '/js_composer/assets/lib/vc_accordion/vc-accordion.min.js' , array( 'jquery' ), null, true );
            wp_register_script( 'vc_tta_autoplay_script', plugins_url() . '/js_composer/assets/lib/vc-tta-autoplay/vc-tta-autoplay.min.js' , array( 'vc_accordion_script' ), null, true );



            wp_enqueue_script( 'vc_accordion_script' );
            if ( ! vc_is_page_editable() ) {
                wp_enqueue_script( 'vc_tta_autoplay_script' );
            }

            wp_register_script( 'vc_tabs_script', plugins_url() . '/js_composer/assets/lib/vc_tabs/vc-tabs.min.js', array( 'vc_accordion_script' ), null, true );
            wp_enqueue_script( 'vc_tabs_script' );

            //single popup image
            wp_register_script( 'prettyphoto', plugins_url() . '/js_composer/assets/lib/prettyphoto/js/jquery.prettyPhoto.min.js', array( 'jquery' ), null , true );

            wp_enqueue_script( 'prettyphoto' );
        }

        wp_enqueue_style('bloomplugins-css', get_template_directory_uri() . '/css/plugins.css',array(), null);
        
        wp_enqueue_style('bloomgoogle-fonts', bloom_google_fonts_url(),array(), null); 

        wp_enqueue_style('bloomtheme-style', get_stylesheet_uri(), array(), '2017-02-10');


        if (!$bloom_options['override-preset']) {
            wp_enqueue_style('bloom-color', get_template_directory_uri() . '/css/color-'.$bloom_options['color-preset'].'.css',array(), null);
        }
        if($bloom_options['enable_ajax_transition']){
            wp_enqueue_style('js_composer_front', plugins_url() . '/js_composer/assets/css/js_composer.min.css',array(), null);
        }
        wp_enqueue_style('bloomcustom-css', get_template_directory_uri() . '/css/custom.css',array(), null);
        
        if ($bloom_options['override-preset']) {
            $inline_style = bloom_overridestyle();
            if (!empty($inline_style)) {
                wp_add_inline_style('bloomcustom-css', $inline_style);
            }
        }
        
        $inline_custom_style = trim($bloom_options['custom-css']);

        if(isset($bloom_options['custom-css-medium']) && !empty($bloom_options['custom-css-medium'])){
            $inline_custom_style .= '@media only screen and  (max-width: 1036px){'.trim($bloom_options['custom-css-medium']).'}';
        }
        if(isset($bloom_options['custom-css-tablet']) && !empty($bloom_options['custom-css-tablet'])){
            $inline_custom_style .= '@media only screen and  (max-width: 756px){'.trim($bloom_options['custom-css-tablet']).'}';
        }
        if(isset($bloom_options['custom-css-mobile']) && !empty($bloom_options['custom-css-mobile'])){
            $inline_custom_style .= '@media only screen and  (max-width: 540px){'.trim($bloom_options['custom-css-mobile']).'}';
        }
        
        if (!empty($inline_custom_style)) {
            wp_add_inline_style('bloomcustom-css', bloom_stripWhitespace($inline_custom_style) );
        }
    }
}
add_action('wp_enqueue_scripts', 'bloom_scripts_styles');

/**
 * Enqueue admin scripts and styles.
 *
 * @since Bloom 1.0
 */

if (!function_exists('bloom_enqueue_admin_scripts')) {
    function bloom_enqueue_admin_scripts() {
        
        wp_enqueue_style('bloomadmin-styles', get_template_directory_uri() . '/inc/assets/admin_styles.css');
    }
}
add_action('admin_enqueue_scripts', 'bloom_enqueue_admin_scripts');



/**
 * Modify menu link class attribute
 *
 * @since Bloom 1.0
 */
$bloom_menu_link_class = array();

add_filter('nav_menu_css_class', 'bloom_nav_menu_css_class_func', 10, 2);

function bloom_nav_menu_css_class_func($classes, $item) {
    global $bloom_menu_link_class;
    $bloom_menu_link_class = array();
    $ajax_menu = array_search("ajax", $classes);
    if ($ajax_menu !== false) {
        $bloom_menu_link_class[] = 'ajax';
        unset($classes['ajax']);
    }
    $external_menu = array_search("external", $classes);
    if ($external_menu !== false) {
        $bloom_menu_link_class[] = 'external';
    }
    //scroll menu for multipage menu
    $menu_scroll_link_menu = array_search("menu-scroll-link", $classes);
    if ($menu_scroll_link_menu !== false) {
        $bloom_menu_link_class[] = 'menu-scroll-link';
    }
    $current_menu = array_search("current-menu-item", $classes);
    if ($current_menu !== false) {
        $bloom_menu_link_class[] = 'act-link';
    }
    $current_menu_ancestor = array_search("current-menu-ancestor", $classes);
    if ($current_menu_ancestor !== false) {
        $bloom_menu_link_class[] = 'ancestor-act-link';
    }
    $current_menu_parent = array_search("current-menu-parent", $classes);
    if ($current_menu_parent !== false) {
        $bloom_menu_link_class[] = 'parent-act-link';
    }
    return $classes;
}

add_filter('nav_menu_link_attributes', 'bloom_nav_menu_link_attributes_func', 10, 3);

function bloom_nav_menu_link_attributes_func($atts, $item, $args) {
    global $bloom_menu_link_class;
    if (!empty($bloom_menu_link_class)) {
        $atts['class'] = implode(" ", $bloom_menu_link_class);
    }
    
    return $atts;
}

/**
 * Left page fixed title
 *
 * @since Bloom 1.0
 */
if (!function_exists('bloom_dynamic_title')) {
    function bloom_dynamic_title() {
        
        // Get the query & post information
        global $post, $wp_query;
        global $bloom_options;
        if (!is_home()) {
            if(is_author()){
                echo sprintf( __( 'Author: %s','bloom' ), get_the_author() );
            }else
            if (is_archive() && !is_tax()) {
                if (is_post_type_archive('portfolio')) {
                    esc_html_e('Our Portfolio', 'bloom');
                } 
                else {
                    if( bloom_is_woocommerce_activated() ){
                        if(is_shop()) echo get_the_title( wc_get_page_id( 'shop' ) );
                    }else{
                        echo get_the_archive_title();
                    }
                    
                }
            } 
            else if (is_archive() && is_tax()) {
                
                // If post is a custom post type
                $post_type = get_post_type();
                
                // If it is a custom post type display name and link
                if ($post_type && $post_type == 'portfolio') {
                    $term = $wp_query->get_queried_object();
                    echo esc_attr($term->name);
                } 
                elseif ($post_type && $post_type != 'post') {
                    
                    $post_type_object = get_post_type_object($post_type);
                    
                    echo esc_attr($post_type_object->labels->name);
                }
            } 
            else if (is_single()) {
                echo get_the_title();
            } 
            else if (is_category()) {
            } 
            else if (is_page()) {
                echo get_the_title();
            } 
            else if (is_search()) {
                echo esc_html__('Search Blog', 'bloom');
            } 
            elseif (is_404()) {
                echo esc_html__('Page not found', 'bloom');
            }
        } 
        else {
            echo esc_attr($bloom_options['blog_home_text']);
        }
    }
}

/**
 * Theme pagination
 *
 * @since Bloom 1.0
 */

if (!function_exists('bloom_pagination')) {
    function bloom_pagination($pages = '', $sec_wrap = false) {
        global $wp_query, $wp_rewrite;
        $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;
        if ($pages == '') {
            // global $wp_query;
            $pages = $wp_query->max_num_pages;
            if (!$pages) {
                $pages = 1;
            }
        }
        $pagination = array('base' => str_replace(999999999, '%#%', get_pagenum_link(999999999)), 'format' => '', 'current' => max(1, get_query_var('paged')), 'total' => $pages, 'prev_text' => wp_kses(__('<i class="fa fa-chevron-left"></i>','bloom'),array('i'=>array('class'=>array(),),) ) , 'next_text' => wp_kses(__('<i class="fa fa-chevron-right"></i>','bloom'),array('i'=>array('class'=>array(),),) ), 'type' => 'plain', 'end_size' => 3, 'mid_size' => 3);
        $return = paginate_links($pagination);
        $return = str_replace(array('page-numbers', 'next', 'prev', 'current'), array('blog-page transition ajax', 'nextposts-link', 'prevposts-link', 'current-page'), $return);
        if (!empty($return)) {
            if ($sec_wrap) echo '<div class="clearfix"></div><section class="custom_folio_pagi">';
            echo '<div class="clearfix"></div><div class="pagination-blog">' . $return . '</div>';
            if ($sec_wrap) echo '</section>';
        }
    }
}

/**
 * Pagination for Portfolio page templates
 *
 * @since Bloom 1.0
 */
if (!function_exists('bloom_custom_pagination')) {
    function bloom_custom_pagination($pages = '', $range = 2, $current_query = '', $sec_wrap = false) {
        // var_dump($pages);die;
        $showitems = ($range * 2) + 1;
        
        if ($current_query == '') {
            global $paged;
            if (empty($paged)) $paged = 1;
        } 
        else {
            $paged = $current_query->query_vars['paged'];
        }
        
        if ($pages == '') {
            if ($current_query == '') {
                global $wp_query;
                $pages = $wp_query->max_num_pages;
                if (!$pages) {
                    $pages = 1;
                }
            } 
            else {
                $pages = $current_query->max_num_pages;
            }
        }
        
        if (1 < $pages) {
            if ($sec_wrap) echo '<div class="clearfix"></div><section class="custom_folio_pagi">';

            
            echo '<div class="clearfix"></div><div class="pagination-blog">';
            
            if ($paged > 1) echo '<a href="' . get_pagenum_link($paged - 1) . '" class="prevposts-link transition ajax">'.wp_kses(__('<i class="fa fa-chevron-left"></i>','bloom'),array('i'=>array('class'=>array(),),) ).'</a>';
            
            for ($i = 1; $i <= $pages; $i++) {
                if (1 != $pages && (!($i >= $paged + $range + 1 || $i <= $paged - $range - 1) || $pages <= $showitems)) {
                    echo ($paged == $i) ? "<span class='blog-page current-page transitiona'>" . $i . "</span>" : "<a href='" . get_pagenum_link($i) . "' class='blog-page transition ajax' >" . $i . "</a>";
                }
            }
            
            if ($paged < $pages) echo '<a href="' . get_pagenum_link($paged + 1) . '" class="nextposts-link transition ajax">'.wp_kses(__('<i class="fa fa-chevron-right"></i>','bloom'),array('i'=>array('class'=>array(),),) ).'</a>';
            
            echo "</div>";
            
            if ($sec_wrap) echo "</section>";
        }

    }
}

/**
 * Blog post nav
 *
 * @since Bloom 1.0
 */
if (!function_exists('bloom_post_nav')) {
    function bloom_post_nav() {
        global $post;
        global $bloom_options;
        if(!$bloom_options['blog_single_navigation'])
            return ;
?>
<div class="clearfix"></div>
<div class="page_nav main-page-nav single-nav">
<?php
$prev_post = get_adjacent_post( $bloom_options['blog_single_nav_same_term'], '', true );
if ( is_a( $prev_post, 'WP_Post' ) ) :
?>
    <a href="<?php echo get_permalink( $prev_post->ID ); ?>" class="arrow-nav lef-ar-nav ajax" title="<?php echo get_the_title($prev_post->ID ); ?>"><i class="fa fa-angle-double-left" aria-hidden="true"></i> <?php echo get_the_title($prev_post->ID ); ?></a>
<?php endif ?>
<?php if( $bloom_options['blog_list_link'] != '' ) :?>
    <ul>
        <li><a href="<?php echo esc_url( $bloom_options['blog_list_link'] ); ?>" class="ajax"><i class="fa fa-th"></i></a></li>
    </ul>
<?php endif;?>
<?php
$next_post = get_adjacent_post( $bloom_options['blog_single_nav_same_term'], '', false );
if ( is_a( $next_post, 'WP_Post' ) ) :
?>
    <a href="<?php echo get_permalink( $next_post->ID ); ?>" class="arrow-nav rig-ar-nav ajax" title="<?php echo get_the_title($next_post->ID ); ?>"><?php echo get_the_title($next_post->ID ); ?> <i class="fa fa-angle-double-right" aria-hidden="true"></i></a>
<?php endif ?>
</div>
    <?php
    }
}

/**
 * Blog post nav
 *
 * @since Bloom 1.0
 */
if (!function_exists('bloom_post_nav_right_column')) {
    function bloom_post_nav_right_column() {
        global $post;
        global $bloom_options;
        if(!$bloom_options['blog_single_navigation'])
            return ;
?>
<div class="blog-nav fl-wrap">
<?php
$prev_post = get_adjacent_post( $bloom_options['blog_single_nav_same_term'], '', true );
if ( is_a( $prev_post, 'WP_Post' ) ) :
?>
    <a href="<?php echo get_permalink( $prev_post->ID ); ?>" class="prev-article ajax">
    <?php if(has_post_thumbnail( $prev_post->ID )) : ?>
        <div class="art-nav-img"><?php echo get_the_post_thumbnail( $prev_post->ID );?></div>
    <?php endif;?>
        <span class="art-nav-it"><?php esc_html_e('Previous','bloom' );?></span>
        <span class="art-nav-name"><?php echo get_the_title($prev_post->ID ); ?></span>
    </a>
<?php endif ?>

<?php if( $bloom_options['blog_list_link'] != '' ) :?>
    <ul>
        <li><a href="<?php echo esc_url( $bloom_options['blog_list_link'] ); ?>" class="ajax list-articles"><i class="fa fa-th"></i></a></li>
    </ul>
<?php endif;?>

<?php
$next_post = get_adjacent_post( $bloom_options['blog_single_nav_same_term'], '', false );
if ( is_a( $next_post, 'WP_Post' ) ) :
?>
    <a href="<?php echo get_permalink( $next_post->ID ); ?>" class="next-article ajax">
        <?php if(has_post_thumbnail( $next_post->ID )) : ?>
            <div class="art-nav-img"><?php echo get_the_post_thumbnail( $next_post->ID );?></div>
        <?php endif;?>
        <span class="art-nav-it"><?php esc_html_e('Next','bloom' );?></span>
        <span class="art-nav-name"><?php echo get_the_title($next_post->ID ); ?></span>
    </a>
<?php endif ?>
</div>
    <?php
    }
}

/**
 * Custom comments list
 *
 * @since Bloom 1.0
 */
if (!function_exists('bloom_comments')) {
    function bloom_comments($comment, $args, $depth) {
        $GLOBALS['comment'] = $comment;
        extract($args, EXTR_SKIP);
        
        if ('div' == $args['style']) {
            $tag = 'div';
            $add_below = 'comment';
        } 
        else {
            $tag = 'li';
            $add_below = 'div-comment';
        }
?>
        <<?php
        echo esc_attr($tag); ?> <?php
        comment_class(empty($args['has_children']) ? 'media' : 'media parent') ?> id="comment-<?php
        comment_ID() ?>">
        <?php
        if ('div' != $args['style']): ?>
        <div id="div-comment-<?php
            comment_ID() ?>" class="comment-body thecomment">
        <?php
        endif; ?>

            <div class="comment-author author-img">
                <?php
        if ($args['avatar_size'] != 0) echo get_avatar($comment, $args['avatar_size']); ?>
            </div>

            <div class="comment-text">
                <span class="author"><?php
        echo get_comment_author_link($comment->comment_ID); ?></span>
                <?php comment_text(); ?>
                <span class="date"><?php echo get_comment_date(esc_html__('F j, Y g:i a', 'bloom')); ?></span>
                <span class="reply">
                <?php comment_reply_link(array_merge($args, array('add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
                </span>
            </div>
            <?php
            if ($comment->comment_approved == '0'): ?>
                    <em class="comment-awaiting-moderation aligncenter"><?php
                esc_html_e('Your comment is awaiting moderation.', 'bloom'); ?></em>
                    <br />
                <?php
            endif; ?>
        
        
        
        <?php
        if ('div' != $args['style']): ?>
        </div> 


        <?php
        endif; ?>

    <?php
    }
}

/**
 * Modify tag cloud format
 *
 * @since Bloom 1.0
 */
function bloom_custom_tag_cloud_widget($args) {
    $args['format']     = 'flat'; //flat,list,array
    $args['smallest']   = 11;
    $args['largest']    = 11;
    $args['unit']       = 'px';
     //ul with a class of wp-tag-cloud
    return $args;
}
add_filter('widget_tag_cloud_args', 'bloom_custom_tag_cloud_widget');

/**
 * Return attachment image link by using wp_get_attachment_image_src function
 *
 * @since Bloom 2.4
 */
function bloom_get_attachment_thumb_link( $id, $size = 'thumbnail', $icon = false ){
    $image_attributes = wp_get_attachment_image_src( $id, $size, $icon );
    if ( $image_attributes ) {
        return $image_attributes[0];
    }
    return '';
}


/** 
 * Filter the body_class for global configuration
 * 
 * @since 1.0
 */ 
// Apply filter
add_filter('body_class', 'bloom_body_classes');
if(!function_exists('bloom_body_classes')){
    function bloom_body_classes($classes) {
            global $bloom_options;
            $classes[] = 'bloom-body-classes';
            $demo_color = get_query_var( 'color', 'light');
            //var_dump($demo_color);
            if($demo_color == 'dark') {
                $bloom_options['color-preset'] = 'dark';
            }
            if(isset($bloom_options['color-preset']) && $bloom_options['color-preset'] == 'dark'){
                $classes[] = 'bloom-dark-version';
            }else{
                $classes[] = 'bloom-light-version';
            }
            return $classes;
    }
}
/** 
 * Echo VC custom style for ajax page transition
 * 
 * @since 1.0
 */ 
if(!function_exists('bloom_echo_vc_custom_styles')){
    function bloom_echo_vc_custom_styles(){
        global $post, $bloom_options;

        if( $bloom_options['enable_ajax_transition'] && isset($post) ){
            $cus_style_metas = get_post_meta( $post->ID, '_wpb_shortcodes_custom_css', true );
            $post_custom_css = get_post_meta( $post->ID, '_wpb_post_custom_css', true );
            if(!empty($cus_style_metas) || !empty($post_custom_css)){
                echo '<div id="ajax-page-inline-div-css" class="no-dis" type="text/css">'.esc_attr($post_custom_css).esc_attr($cus_style_metas).'</div>';
            }
        }
        
    }
}

/** 
 * Global variables fix
 * https://forums.envato.com/t/redux-framework-global-variable-issue/36739
 * @since Bloom 1.0
 */ 
if ( !function_exists('bloom_global_var') ) {
    function bloom_global_var($opt_1 = '', $opt_2 = '', $opt_check = false){
        global $bloom_options;
        if( $opt_check ) {
            if(isset($bloom_options[$opt_1][$opt_2])) {
                return $bloom_options[$opt_1][$opt_2];
            }
        } else {
            if(isset($bloom_options[$opt_1])) {
                return $bloom_options[$opt_1];
            }
        }

        return false;
        
    }
}
if(!function_exists('bloom_get_template_part')){
    /**
     * Load a template part into a template
     *
     * Makes it easy for a theme to reuse sections of code in a easy to overload way
     * for child themes.
     *
     * Includes the named template part for a theme or if a name is specified then a
     * specialised part will be included. If the theme contains no {slug}.php file
     * then no template will be included.
     *
     * The template is included using require, not require_once, so you may include the
     * same template part multiple times.
     *
     * For the $name parameter, if the file is called "{slug}-special.php" then specify
     * "special".
      * For the var parameter, simple create an array of variables you want to access in the template
     * and then access them e.g. 
     * 
     * array("var1=>"Something","var2"=>"Another One","var3"=>"heres a third";
     * 
     * becomes
     * 
     * $var1, $var2, $var3 within the template file.
     *
     * @since 3.0.0
     *
     * @param string $slug The slug name for the generic template.
     * @param string $name The name of the specialised template.
     * @param array $vars The list of variables to carry over to the template
     * @author CTHthemes 
     * @ref http://www.zmastaa.com/2015/02/06/php-2/wordpress-passing-variables-get_template_part
     * @ref http://keithdevon.com/passing-variables-to-get_template_part-in-wordpress/
     */
    function bloom_get_template_part( $slug, $name = null, $vars = null ) {

        $template = "{$slug}.php";
        $name = (string) $name;
        if ( '' !== $name && ( file_exists( get_stylesheet_directory() ."/{$slug}-{$name}.php") || file_exists( get_template_directory() ."/{$slug}-{$name}.php") ) ) {
            $template = "{$slug}-{$name}.php";
        }

        extract($vars);
        include(locate_template($template));
    }
}


function bloom_get_current_url(){
    global $wp;
    $current_url = home_url(add_query_arg(array(),$wp->request));

    return $current_url;
}

/**
* Add custom query vars for demo
*
* @since Bloom 1.0
*/
function bloom_query_vars_filter( $vars ){
  $vars[] = "color";
  return $vars;
}
add_filter( 'query_vars', 'bloom_query_vars_filter' );

/**
* Remove default Recent Comments widget style
*
* @since Bloom 1.0
*/

function bloom_remove_recent_comments_widget_style(){
    return;
}
add_filter('show_recent_comments_widget_style','bloom_remove_recent_comments_widget_style' , 0 );

if(!function_exists('bloom_password_form')){
    function bloom_password_form() {
        global $post;
        $label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
        $o = '<div class="bloom-password-form-holder"><form action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post" class="bloom-password-form"><p>' . esc_html__( "To view this protected post, enter the password below:" ,'bloom') . '</p><label for="' . $label . '">' . esc_html__( "Password:" ,'bloom') . ' </label><div class="password-input-wrap"><input name="post_password" id="' . $label . '" type="password" size="20" maxlength="20" class="password-input" /></div><div class="clearfix"></div><div class="password-submit-holder"><button class="password-submit btn anim-button" type="submit"><i class="fa fa-eye"></i> <span>' . esc_attr__( "Submit" ,'bloom' ) . '</span></button></div></form></div>';
        return $o;
    }
}

add_filter( 'the_password_form', 'bloom_password_form' );

/**
 * Custom meta box for page, post, portfolio...
 *
 * @since Bloom 1.0
 */
require_once get_template_directory() . '/cmb2/functions.php';

/**
 * Visual Composer plugin integration
 *
 * @since Bloom 1.0
 */
require_once get_template_directory() . '/inc/cth_for_vc.php';

/**
 * Theme custom style
 *
 * @since Bloom 1.0
 */
require_once get_template_directory() . '/inc/overridestyle.php';

/**
 * Taxonomy meta box
 *
 * @since Bloom 1.0
 */
require_once get_template_directory() . '/inc/cth_taxonomy_fields.php';
require_once get_template_directory() . '/inc/portfolio_cat_metabox_fields.php';
require_once get_template_directory() . '/inc/category_metabox_fields.php';
require_once get_template_directory() . '/inc/tag_metabox_fields.php';

/**
 * Custom elements for VC
 *
 * @since Bloom 1.0
 */
require_once get_template_directory() . '/vc_extend/vc_shortcodes.php';

/**
 * Implement Post views
 *
 * @since Bloom 1.0
 */
//require_once get_template_directory() . '/inc/post_views.php';

/**
 * Implement Ajax requests
 *
 * @since Bloom 1.0
 */
require_once get_template_directory() . '/inc/ajax.php';

/**
 * Implement the One Click Demo Import plugin
 *
 * @since Bloom 1.0
 */
require_once get_template_directory() . '/includes/one-click-import-data.php';

/**
 * Woocommerce support
 *
 * @since Bloom 2.0
 */

if ( ! function_exists( 'bloom_is_woocommerce_activated' ) ) {
    function bloom_is_woocommerce_activated() {
        if ( class_exists( 'woocommerce' ) ) { return true; } else { return false; }
    }
}


/**
 * Include the TGM_Plugin_Activation class.
 */
require_once get_template_directory() . '/framework/class-tgm-plugin-activation.php';

add_action('tgmpa_register', 'bloom_register_required_plugins');

/**
 * Register the required plugins for this theme.
 *
 * In this example, we register five plugins:
 * - one included with the TGMPA library
 * - two from an external source, one from an arbitrary source, one from a GitHub repository
 * - two from the .org repo, where one demonstrates the use of the `is_callable` argument
 *
 * The variables passed to the `tgmpa()` function should be:
 * - an array of plugin arrays;
 * - optionally a configuration array.
 * If you are not changing anything in the configuration array, you can remove the array and remove the
 * variable from the function call: `tgmpa( $plugins );`.
 * In that case, the TGMPA default settings will be used.
 *
 * This function is hooked into `tgmpa_register`, which is fired on the WP `init` action on priority 10.
 */
function bloom_register_required_plugins() {
    /*
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(

        // This is an example of how to include a plugin from a private repo in your theme.
        array(
            'name' => esc_html__('Redux Framework','bloom'),
             // The plugin name.
            'slug' => 'redux-framework',
             // The plugin slug (typically the folder name).
            'required' => true,
             // If false, the plugin is only 'recommended' instead of required.
            'external_url' => esc_url('https://wordpress.org/plugins/redux-framework/'),
             // If set, overrides default API URL and points to an external URL.
        ), 
        array(
            'name' => esc_html__('WPBakery Page Builder','bloom'),
             // The plugin name.
            'slug' => 'js_composer',
             // The plugin slug (typically the folder name).
            'source' => 'http://assets.cththemes.com/plugins/js_composer.zip',
             // The plugin source.
            'required' => true,
             // If false, the plugin is only 'recommended' instead of required.
            'external_url' => 'https://codecanyon.net/item/visual-composer-page-builder-for-wordpress/242431',
             // If set, overrides default API URL and points to an external URL.
        ), 
        array(
            'name' => esc_html__('Contact Form 7','bloom'),
             // The plugin name.
            'slug' => 'contact-form-7',
             // The plugin slug (typically the folder name).
            'required' => true,
             // If false, the plugin is only 'recommended' instead of required.
            'external_url' => esc_url('https://wordpress.org/plugins/contact-form-7/' ),
             // If set, overrides default API URL and points to an external URL.
        ), 

        array(
            'name' => esc_html__('CMB2','bloom'),
             // The plugin name.
            'slug' => 'cmb2',
             // The plugin slug (typically the folder name).
            'required' => true,
             // If false, the plugin is only 'recommended' instead of required.
            'external_url' => esc_url('https://wordpress.org/support/plugin/cmb2'),
             // If set, overrides default API URL and points to an external URL.
        ),
        array(
            'name' => esc_html__('Bloom Add-ons','bloom' ),
             // The plugin name.
            'slug' => 'bloom_add_ons',
             // The plugin slug (typically the folder name).
            'source' => get_template_directory_uri() . '/framework/plugins/bloom_add_ons.zip',
             // The plugin source.
            'required' => true,
             // If false, the plugin is only 'recommended' instead of required.
        ), 

        
        array(
            'name' => esc_html__('Envato Market','bloom' ),
             // The plugin name.
            'slug' => 'envato-market',
             // The plugin slug (typically the folder name).
            'source' => esc_url('http://envato.github.io/wp-envato-market/dist/envato-market.zip' ),
             // The plugin source.
            'required' => true,
             // If false, the plugin is only 'recommended' instead of required.
            'external_url' => esc_url('http://envato.github.io/wp-envato-market/' ),
             // If set, overrides default API URL and points to an external URL.
        ),

        array('name' => esc_html__('One Click Demo Import','bloom'),
             // The plugin name.
            'slug' => 'one-click-demo-import',
             // The plugin slug (typically the folder name).
            'required' => true,
             // If false, the plugin is only 'recommended' instead of required.
            'external_url' => esc_url('https://wordpress.org/plugins/one-click-demo-import/'),
             // If set, overrides default API URL and points to an external URL.
        ),

        array('name' => esc_html__('Regenerate Thumbnails','bloom'),
             // The plugin name.
            'slug' => 'regenerate-thumbnails',
             // The plugin slug (typically the folder name).
            'required' => false,
             // If false, the plugin is only 'recommended' instead of required.
            'external_url' => esc_url('https://wordpress.org/plugins/regenerate-thumbnails/' ),
             // If set, overrides default API URL and points to an external URL.
        ),

    );

    /*
     * Array of configuration settings. Amend each line as needed.
     *
     * TGMPA will start providing localized text strings soon. If you already have translations of our standard
     * strings available, please help us make TGMPA even better by giving us access to these translations or by
     * sending in a pull-request with .po file(s) with the translations.
     *
     * Only uncomment the strings in the config array if you want to customize the strings.
     */
    $config = array(
        'id'           => 'bloom',                 // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                      // Default absolute path to bundled plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.

        
    );

    tgmpa( $plugins, $config );
}

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328091&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        