<?php

/**
 *
 * @package Bloom - Responsive Architecture Theme
 * @author Cththemes - http://themeforest.net/user/cththemes
 * @date: 16-02-2017
 *
 * @copyright  Copyright ( C ) 2015 cththemes.com . All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 */

if (!function_exists('bloom_hex2rgb')) {
    function bloom_hex2rgb($hex) {
        
        $hex = str_replace("#", "", $hex);
        
        if (strlen($hex) == 3) {
            $r = hexdec(substr($hex, 0, 1) . substr($hex, 0, 1));
            $g = hexdec(substr($hex, 1, 1) . substr($hex, 1, 1));
            $b = hexdec(substr($hex, 2, 1) . substr($hex, 2, 1));
        } 
        else {
            $r = hexdec(substr($hex, 0, 2));
            $g = hexdec(substr($hex, 2, 2));
            $b = hexdec(substr($hex, 4, 2));
        }
        $rgb = array($r, $g, $b);
        return $rgb;
    }
}
if (!function_exists('bloom_colourBrightness')) {
    
    /*
     * $hex = '#ae64fe';
     * $percent = 0.5; // 50% brighter
     * $percent = -0.5; // 50% darker
    */
    function bloom_colourBrightness($hex, $percent) {
        
        // Work out if hash given
        $hash = '';
        if (stristr($hex, '#')) {
            $hex = str_replace('#', '', $hex);
            $hash = '#';
        }
        
        /// HEX TO RGB
        $rgb = bloom_hex2rgb($hex);
        
        //// CALCULATE
        for ($i = 0; $i < 3; $i++) {
            
            // See if brighter or darker
            if ($percent > 0) {
                
                // Lighter
                $rgb[$i] = round($rgb[$i] * $percent) + round(255 * (1 - $percent));
            } 
            else {
                
                // Darker
                $positivePercent = $percent - ($percent * 2);
                $rgb[$i] = round($rgb[$i] * $positivePercent) + round(0 * (1 - $positivePercent));
            }
            
            // In case rounding up causes us to go to 256
            if ($rgb[$i] > 255) {
                $rgb[$i] = 255;
            }
        }
        
        //// RBG to Hex
        $hex = '';
        for ($i = 0; $i < 3; $i++) {
            
            // Convert the decimal digit to hex
            $hexDigit = dechex($rgb[$i]);
            
            // Add a leading zero if necessary
            if (strlen($hexDigit) == 1) {
                $hexDigit = "0" . $hexDigit;
            }
            
            // Append to the hex string
            $hex.= $hexDigit;
        }
        return $hash . $hex;
    }
}
if (!function_exists('bloom_bg_png')) {
    function bloom_bg_png($color, $input, $output) {
        $image = imagecreatefrompng($input);
        $rgbs = bloom_hex2rgb($color);
        $background = imagecolorallocate($image, $rgbs[0], $rgbs[1], $rgbs[2]);
        
        imagepng($image, $output);
    }
}

if (!function_exists('bloom_stripWhitespace')) {
    
    /**
     * Strip whitespace.
     *
     * @param  string $content The CSS content to strip the whitespace for.
     * @return string
     */
    function bloom_stripWhitespace($content) {
        
        // remove leading & trailing whitespace
        $content = preg_replace('/^\s*/m', '', $content);
        $content = preg_replace('/\s*$/m', '', $content);
        
        // replace newlines with a single space
        $content = preg_replace('/\s+/', ' ', $content);
        
        // remove whitespace around meta characters
        // inspired by stackoverflow.com/questions/15195750/minify-compress-css-with-regex
        $content = preg_replace('/\s*([\*$~^|]?+=|[{};,>~]|!important\b)\s*/', '$1', $content);
        $content = preg_replace('/([\[(:])\s+/', '$1', $content);
        $content = preg_replace('/\s+([\]\)])/', '$1', $content);
        $content = preg_replace('/\s+(:)(?![^\}]*\{)/', '$1', $content);
        
        // whitespace around + and - can only be stripped in selectors, like
        // :nth-child(3+2n), not in things like calc(3px + 2px) or shorthands
        // like 3px -2px
        $content = preg_replace('/\s*([+-])\s*(?=[^}]*{)/', '$1', $content);
        
        // remove semicolon/whitespace followed by closing bracket
        $content = preg_replace('/;}/', '}', $content);
        
        return trim($content);
    }
}

if (!function_exists('bloom_add_rgba_background_inline_style')) {
    function bloom_add_rgba_background_inline_style($color = '#ed5153', $handle = 'skin') {
        $inline_style = '.testimoni-wrapper,.pricing-wrapper,.da-thumbs li  article,.team-caption,.home-centered{background-color:rgba(' . implode(",", hex2rgb($color)) . ', 0.9);}';
        wp_add_inline_style($handle, $inline_style);
    }
}

if (!function_exists('bloom_overridestyle')) {
    function bloom_overridestyle() {
        global $bloom_options;



$main2rgb = bloom_hex2rgb($bloom_options['main-theme-color']);
        
$inline_style = 'body {background-color:' . $bloom_options['main-bg-color'] . ';color:' . $bloom_options['main-theme-color'] . ';}
a {color:'.$bloom_options['hyperlink-text-color']['regular'].';}
a:hover {color:'.$bloom_options['hyperlink-text-color']['hover'].';}
a:active,a:focus {color:'.$bloom_options['hyperlink-text-color']['active'].';}
p {color:'.$bloom_options['paragraph-color'].';}
.tm-loader #circle{
    border: 2px solid  ' . $bloom_options['theme-loader-color'] . ';
}
.tm-loader #circle   {
    border-bottom: 2px solid ' . $bloom_options['main-theme-color'] . ';
}
blockquote p {
    color:' . $bloom_options['main-theme-color'] . ';
}
.hide-desktop-form:before,
.contact-form-holder:before , .info-wrap , .fixed-filter , .content-holder  , .column-wrap , .content  , header , .nav-button .nbs:before  ,footer , section , article.single-article , #portfolio_horizontal_container , .owl-thumbs , .owl-thumb-item:before , .gallery_horizontal  , .vis-pan , .back-link{
    background: ' . $bloom_options['main-bg-color'] . ';
}

header {
    background: ' . $bloom_options['header-color'] . ';
}
footer{
   background: ' . $bloom_options['footer-bg-color'] . ';
}

.info-wrap  , .nav-inner{
    background:' . $bloom_options['main-bg-color'] . ';
}
.header-info ul li  span  , .section-title h2 span , .inf-mob-btn span{
    color:' . $bloom_options['main-theme-color'] . ';
}
.main-sidebar-widget h3.wid-title,
.post-author-wrap h3 a,
.header-info ul li  a , .footer-social li a span , .policy-box , .column-filter .gallery-filters a , .contact-list li span  , .share-holder  span {
    color: ' . $bloom_options['main-theme-color'] . ';
}
.section-title a,
.blog-opt a,
.nav-button .nav-text  , .serv-item  span , .custom-skillbar-title span , .fixed-filter .gallery-filters a , .show-thumbs , .show-info , .art-date  , .blog-cat li  , .post-author-wrap span {
    color:' . $bloom_options['main-theme-color'] . ';
}
.show-thumbs , .show-info {
    color:' . $bloom_options['main-theme-color'] . ';
}
.nav-button span  , #respond #submit:hover  {
    background:' . $bloom_options['main-theme-color'] . ';
}
.custom-skillbar {
    background:' . $bloom_options['main-theme-color'] . ';
}
.num-holder2  {
    color:' . $bloom_options['main-theme-color'] . ';
}
.sliding-menu a.ancestor-act-link:before,
.sliding-menu a.parent-act-link:before,
.sliding-menu a.act-link:before{
    background: ' . $bloom_options['active-menu-bg-color'] . ';
}
.btn {
    color:' . $bloom_options['main-bg-color'] . ';
    border:2px solid ' . $bloom_options['main-theme-color'] . ';
    background:' . $bloom_options['main-theme-color'] . ';
}
.skill-name  , .fixed-filter .gallery-filters a.gallery-filter-active  , .inline-filter .gallery-filters a.gallery-filter-active , #contact-form input[type="text"] , #contact-form textarea , #comment-form input[type="text"]  , #comment-form textarea  , #success_page p  , .post-author-wrap p , #respond h3 a  , #respond input , .to-top{
    color:' . $bloom_options['main-theme-color'] . ';
}
.skillbar-bg {
    background:' . $bloom_options['main-theme-color'] . ';
}
.team-social li a , .serv-item h3  {
    color:' . $bloom_options['main-theme-color'] . ';
}
.team-info h4 {
    color: ' . $bloom_options['main-theme-color'] . ';
}
.inline-filter .gallery-filters a  , .pagination-blog a{
    color:' . $bloom_options['main-theme-color'] . ';
}
.blog-header-none .section-title:after,
.show-info:before  , .post-comments-wrap span.reply a {
    background:' . $bloom_options['main-theme-color'] . ';
}
#contact-form #submit {
 
    border:2px solid ' . $bloom_options['main-theme-color'] . ';
    background:' . $bloom_options['main-theme-color'] . ';
}
.close-contact:after , .close-contact:before  , .close-info:before , .close-info:after{
    background:' . $bloom_options['main-theme-color'] . ';
}
.share-holder.trns-share span ,   #respond h3 small a   , #respond #submit,.wpcf7 .wpcf7-submit  , #contact-form #submit   , .blog-cat li a{
    color:' . $bloom_options['main-bg-color'] . ';
}
 .post-comments-wrap span.reply a ,  #respond #submit:hover{
    color:' . $bloom_options['main-bg-color'] . ';
}
.share-icon {
    color:' . $bloom_options['main-theme-color'] . ';
}
.pagination-blog a.current-page, .pagination-blog a:hover {
    color:' . $bloom_options['main-bg-color'] . ';
    background:' . $bloom_options['main-theme-color'] . ';
}
.post-author {
    border-top:1px solid ' . $bloom_options['main-theme-color'] . ';
}
.main-sidebar-widget h3,
.thecomment  , .post-author , .artcicle-list  , .serv-item {
    border-bottom:1px  solid ' . $bloom_options['main-theme-color'] . ';
}
.thecomment .comment-text em i {
    color:#f3bd00;
}
#respond input  , #respond textarea{
    border:1px solid ' . $bloom_options['main-theme-color'] . ';
    background:' . $bloom_options['main-bg-color'] . ';
    color: ' . $bloom_options['main-theme-color'] . ';
}
#respond #submit,.wpcf7 .wpcf7-submit {
    background:' . $bloom_options['main-theme-color'] . ';
}
 
.to-top:hover {
    color:' . $bloom_options['main-theme-color'] . ';
 
}
blockquote {
    border-left: 15px solid ' . $bloom_options['main-theme-color'] . ';
}
.single-nav {
    border-top: 1px solid ' . $bloom_options['main-theme-color'] . ';
    border-bottom: 1px solid ' . $bloom_options['main-theme-color'] . ';
}
.single-nav a {
    color: ' . $bloom_options['main-theme-color'] . ';
}
.single-nav + .post-author {
    border-top: none;
    margin-top: 0px;
}
div.wpcf7 form input:not([type="submit"]), div.wpcf7 form textarea, #contact-form input[type="text"], #contact-form input[type="email"], #contact-form textarea, #comment-form input[type="text"], #comment-form input[type="email"], #comment-form textarea
{
    color: ' . $bloom_options['main-theme-color'] . ';
}
.bloom-dark-version .hoz-folio-lmore-holder a,.bloom-dark-version .hoz-gal-lmore-holder a {
    color: ' . $bloom_options['main-bg-color'] . ';
}
article.sticky .section-title:after {
    background-color: ' . $bloom_options['main-theme-color'] . ';
}

.sliding-menu a,.sliding-menu a:focus {color:' . $bloom_options['main-nav-menu-color']['regular'] . ';}
.sliding-menu a:hover {color:' . $bloom_options['main-nav-menu-color']['hover'] . ';}
.sliding-menu a.ancestor-act-link, .sliding-menu a.parent-act-link, .sliding-menu a.act-link {color:' . $bloom_options['main-nav-menu-color']['active'] . ';}

.column-title .page-title, .column-title h2 {
    color: ' . $bloom_options['main-bg-color'] . ';
}
.column-title {
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba('.$main2rgb[0].','.$main2rgb[1].','.$main2rgb[2].',0)), color-stop(100%,rgba('.$main2rgb[0].','.$main2rgb[1].','.$main2rgb[2].',0.75)));
    background: -webkit-linear-gradient(top, rgba('.$main2rgb[0].','.$main2rgb[1].','.$main2rgb[2].',0) 0%,rgba('.$main2rgb[0].','.$main2rgb[1].','.$main2rgb[2].',0.75) 100%);
    background: -o-linear-gradient(top, rgba('.$main2rgb[0].','.$main2rgb[1].','.$main2rgb[2].',0) 0%,rgba('.$main2rgb[0].','.$main2rgb[1].','.$main2rgb[2].',0.75) 100%);
    background: -ms-linear-gradient(top, rgba('.$main2rgb[0].','.$main2rgb[1].','.$main2rgb[2].',0) 0%,rgba('.$main2rgb[0].','.$main2rgb[1].','.$main2rgb[2].',0.75) 100%);
    background: linear-gradient(to bottom, rgba('.$main2rgb[0].','.$main2rgb[1].','.$main2rgb[2].',0) 0%,rgba('.$main2rgb[0].','.$main2rgb[1].','.$main2rgb[2].',0.75) 100%);
}

@media only screen and  (max-width: 1036px) {
.header-info ul , .column-filter  {
 
    background:' . $bloom_options['main-theme-color'] . ';
 
}   
} 

';
        
        // Remove whitespace
        $inline_style = bloom_stripWhitespace($inline_style);
        
        return $inline_style;
    }
}
